"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import openapi_client
from openapi_client.model.protection_class import ProtectionClass


class TestProtectionClass(unittest.TestCase):
    """ProtectionClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testProtectionClass(self):
        """Test ProtectionClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ProtectionClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
