"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_bulk_patch_species_analytics_species_patch(self):
        """Test case for bulk_patch_species_analytics_species_patch

        Bulk Patch Species  # noqa: E501
        """
        pass

    def test_get_defendant_analytics_judgment_defendant_get(self):
        """Test case for get_defendant_analytics_judgment_defendant_get

        Get Defendant  # noqa: E501
        """
        pass

    def test_get_judgment_analytics_judgment_judgment_id_get(self):
        """Test case for get_judgment_analytics_judgment_judgment_id_get

        Get Judgment  # noqa: E501
        """
        pass

    def test_get_sources_analytics_judgment_source_get(self):
        """Test case for get_sources_analytics_judgment_source_get

        Get Sources  # noqa: E501
        """
        pass

    def test_get_species_analytics_species_get(self):
        """Test case for get_species_analytics_species_get

        Get Species  # noqa: E501
        """
        pass

    def test_post_defendant_analytics_judgment_defendant_judgment_id_post(self):
        """Test case for post_defendant_analytics_judgment_defendant_judgment_id_post

        Post Defendant  # noqa: E501
        """
        pass

    def test_post_judgment_analytics_judgment_post(self):
        """Test case for post_judgment_analytics_judgment_post

        Post Judgment  # noqa: E501
        """
        pass

    def test_post_source_analytics_judgment_source_judgment_id_post(self):
        """Test case for post_source_analytics_judgment_source_judgment_id_post

        Post Source  # noqa: E501
        """
        pass

    def test_read_root_get(self):
        """Test case for read_root_get

        Read Root  # noqa: E501
        """
        pass

    def test_search_judgments_analytics_judgment_get(self):
        """Test case for search_judgments_analytics_judgment_get

        Search Judgments  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
